@@ -7,7 +7,7 @@ test_that("scientific name empty", {
 
   expect_equal(
     empty_scientific_name,
-    data.frame(
+    dplyr::tibble(
       scientificName = c("Ocotea odorifera", NA, "Panthera onca", ""),
       .scientificName_empty = c(TRUE, FALSE, TRUE, FALSE)
     )
@@ -19,5 +19,5 @@ test_that("data.frame test", {
   empty_scientific_name <-
     bdc_scientificName_empty(data = x, sci_names = "scientificName")
 
-  expect_equal(class(empty_scientific_name), "data.frame")
+  expect_equal(class(empty_scientific_name), c("tbl_df", "tbl", "data.frame"))
 })
